@@ -92,6 +92,8 @@ class Database(core.Construct):
 
         rubrik_backup (str): to enable/disable Rubrik backup using tag `RubrikBackup` - format Boolean (`true`, `false`). Default: true
 
+        cloudwatch_audit_log (str): Applicable only to Oracle instances. If to enable audit logs export in S3. The default is no log exports. Specify this param in case you want to have the audit log export enabled
+
 
     """
     @property
@@ -165,7 +167,8 @@ class Database(core.Construct):
         oracle_license_is_byol=None,
         s3_export_buckets=None,
         s3_import_buckets=None,
-        rubrik_backup=True,
+        rubrik_backup="True",
+        cloudwatch_audit_log=None,
         **kwargs,
     ):
         super().__init__(scope, id, **kwargs)
@@ -210,6 +213,12 @@ class Database(core.Construct):
         self._cluster = None
         self._rds_security_group = None
 
+        to_be_backed_up = (
+            rubrik_backup
+            and isinstance(rubrik_backup, str)
+            and rubrik_backup.lower() == "true"
+        )
+
         # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Validate input params
 
         # TODO
@@ -361,6 +370,8 @@ class Database(core.Construct):
 
             # Default RDS license model is NONE
             license_model=None
+            # Default RDS cloudwatch logs export in NONE
+            cloudwatch_logs_exports=None
 
             if is_oracle:
 
@@ -385,6 +396,16 @@ class Database(core.Construct):
                     # If user specified chancghe to BRING_YOUR_OWN_LICENSE
                     license_model = _rds.LicenseModel.BRING_YOUR_OWN_LICENSE
 
+                should_be_cloudwatch_audit_log = (
+                    cloudwatch_audit_log
+                    and isinstance(cloudwatch_audit_log, str)
+                    and cloudwatch_audit_log.lower() == "true"
+                )
+
+                if should_be_cloudwatch_audit_log:
+                    # If user specified change to cloud watch log setting
+                    cloudwatch_logs_exports = _rds.cloudwatch_logs_exports=["audit"]
+
             self._instance = _rds.DatabaseInstance(
                 self,
                 "instance",
@@ -409,7 +430,8 @@ class Database(core.Construct):
                 processor_features=None,
                 security_groups=security_groups,
                 storage_encryption_key=encryption_key,
-                character_set_name=character_set_name
+                character_set_name=character_set_name,
+                cloudwatch_logs_exports=cloudwatch_logs_exports
             )
 
             # Conditionally create an instance from a snapshot
@@ -428,7 +450,7 @@ class Database(core.Construct):
 
             # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ FAO AWS Rubrik backup tag
 
-            if rubrik_backup:
+            if to_be_backed_up:
                 Tags.of(self._instance).add("RubrikBackup", "true")
             else:
                 Tags.of(self._instance).add("RubrikBackup", "false")
