@@ -284,15 +284,15 @@ class Microservice(core.Construct):
             description="FAO HQ Clients",
         )
         security_group.add_ingress_rule(
-            peer=self.azure_dev_a_as_peer(self._environments_parameters),
+            peer=self.azure_dev_avd_as_peer(self._environments_parameters),
             connection=self.tcp_connection_traffic_port,
-            description="AZURE DEV A",
+            description="Azure Development Virtual Desktop",
         )
 
         security_group.add_ingress_rule(
-            peer=self.azure_dev_b_as_peer(self._environments_parameters),
+            peer=self.azure_dev_cpc_as_peer(self._environments_parameters),
             connection=self.tcp_connection_traffic_port,
-            description="AZURE DEV B",
+            description="Azure Development Cloud PC",
         )
 
         return security_group
@@ -633,30 +633,30 @@ class Microservice(core.Construct):
         return _ec2.Peer.ipv4(fao_networks["fao_hq_clients"])
 
     @staticmethod
-    def azure_dev_a_as_peer(environments_parameters):
-        """Returns the AZURE DEV A network as Peer
+    def azure_dev_avd_as_peer(environments_parameters):
+        """Returns the Azure Development Virtual Desktop network as Peer
 
         Args:
             environments_parameters (dict): The dictionary containing the references to CSI AWS environments. This will simplify the environment promotions and enable a parametric development of the infrastructures.
 
         Returns:
-            aws_ec2.Peer: The AZURE DEV A network as Peer resource
+            aws_ec2.Peer: The Azure Development Virtual Desktop network as Peer resource
         """
         fao_networks = environments_parameters["networking"]
-        return _ec2.Peer.ipv4(fao_networks["azure_dev_a"])
+        return _ec2.Peer.ipv4(fao_networks["azure_dev_avd"])
 
     @staticmethod
-    def azure_dev_b_as_peer(environments_parameters):
-        """Returns the AZURE DEV B network as Peer
+    def azure_dev_cpc_as_peer(environments_parameters):
+        """Returns the The Azure Development Cloud PC network as Peer
 
         Args:
             environments_parameters (dict): The dictionary containing the references to CSI AWS environments. This will simplify the environment promotions and enable a parametric development of the infrastructures.
 
         Returns:
-            aws_ec2.Peer: The AZURE DEV B network as Peer resource
+            aws_ec2.Peer: The Azure Development Cloud PC network as Peer resource
         """
         fao_networks = environments_parameters["networking"]
-        return _ec2.Peer.ipv4(fao_networks["azure_dev_b"])
+        return _ec2.Peer.ipv4(fao_networks["azure_dev_cpc"])
 
 
     def asg_name(self):
@@ -894,10 +894,10 @@ class Microservice(core.Construct):
         self._fao_hq_clients_as_peer = self.fao_hq_clients_as_peer(
             self._environments_parameters
         )
-        self._azure_dev_a_as_peer = self.azure_dev_a_as_peer(
+        self._azure_dev_avd_as_peer = self.azure_dev_avd_as_peer(
             self._environments_parameters
         )
-        self._azure_dev_b_as_peer = self.azure_dev_b_as_peer(
+        self._azure_dev_cpc_as_peer = self.azure_dev_cpc_as_peer(
             self._environments_parameters
         )
         if has_upstream:
@@ -985,14 +985,14 @@ class Microservice(core.Construct):
                     description="FAO HQ Clients",
                 )
                 self.alb_security_group.add_ingress_rule(
-                    peer=self._azure_dev_a_as_peer,
+                    peer=self._azure_dev_avd_as_peer,
                     connection=_ec2.Port.tcp(80),
-                    description="AZURE DEV A",
+                    description="Azure Development Virtual Desktop network",
                 )
                 self.alb_security_group.add_ingress_rule(
-                    peer=self._azure_dev_b_as_peer,
+                    peer=self._azure_dev_cpc_as_peer,
                     connection=_ec2.Port.tcp(80),
-                    description="AZURE DEV B",
+                    description="Azure Development Cloud PC Network",
                 )
             # Used when HTTPS is forced. These rules enable the redirect from HTTP -> HTTPS
             if is_public_has_no_upstream_and_is_https_and_no_cdn:
