@@ -61,6 +61,8 @@ class ServiceUserForIAC(core.Construct):
         # S3 buckets 
         s3_buckets = [
             "arn:aws:s3:::" + app_name + "*", 
+            "arn:aws:s3:::" + app_name.replace("-", "") + "*", 
+            "arn:aws:s3:::" + app_name.replace("-", ".") + "*", 
             "arn:aws:s3:::awsserverlessrepo-changesets-*",
             "arn:aws:s3:::cdktoolkit*",
             "arn:aws:s3:::cdk-*",
@@ -128,7 +130,9 @@ class ServiceUserForIAC(core.Construct):
                         "elasticfilesystem:DescribeFileSystemPolicy",
                         "elasticfilesystem:TagResource",
                         "elasticfilesystem:UntagResource",
-                        "autoscaling:DeletePolicy"
+                        "autoscaling:DeletePolicy",
+                        "cognito-idp:*UserPoolClient",
+                        "cloudfront:TagResource"
                     ],
                     resources=["*"],
                 ),
@@ -238,6 +242,7 @@ class ServiceUserForIAC(core.Construct):
                     ],
                     resources=[
                         "arn:aws:cloudfront:eu-west-1:*:*:*:*" + app_name + "*",
+                        "arn:aws:cloudfront::*:distribution/*"
                     ],
                 ),
                 _iam.PolicyStatement(
@@ -309,7 +314,7 @@ class ServiceUserForIAC(core.Construct):
                     resources=["*"],
                     conditions={
                         "ForAnyValue:StringLike": {
-                             "ec2:ResourceTag/ApplicationName": app_name
+                            "ec2:ResourceTag/ApplicationName": app_name
                         }
                     },
                 ),
@@ -357,11 +362,13 @@ class ServiceUserForIAC(core.Construct):
                         "ssm:Describe*",
                         "ssm:Get*",
                         "ssm:List*",
+                        "ssm:Put*",
+                        "ssm:AddTags*",
                     ],
                     resources=[
                         "arn:aws:ssm:*:"
-                        + account_id
-                        + ":parameter/"
+                        + "*"
+                        + ":parameter/*"
                         + app_name
                         + "*",
                         "arn:aws:ssm:*:"
